==> bitcoin_0.16.3~dfsg.orig.tar.gz: bitcoin-0.16.3/src/qt/locale/bitcoin_am.ts <==
<TS language="am" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>አድራሻ ወይም መለያ ስም ለመቀየር ቀኙን ጠቅ ያድርጉ</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>አዲስ አድራሻ ፍጠር</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;አዲስ</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>አሁን የተመረጠውን አድራሻ ወደ ሲስተሙ ቅንጥብ ሰሌዳ ቅዳ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;ቅዳ</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>ዝጋ</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>አሁን የተመረጠውን አድራሻ ከዝርዝሩ ውስጥ ሰርዝ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>በአሁኑ ማውጫ ውስጥ ያለውን መረጃ ወደ አንድ ፋይል ላክ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ላክ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ሰርዝ</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>ገንዘብ/ኮይኖች የሚልኩለትን አድራሻ ይምረጡ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>ገንዘብ/ኮይኖች የሚቀበሉበትን አድራሻ ይምረጡ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>ምረጥ</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>የመላኪያ አድራሻዎች</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>የመቀበያ አድራሻዎች</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>እነኚ የቢትኮይን ክፍያ የመላኪያ አድራሻዎችዎ ናቸው:: ገንዘብ/ኮይኖች ከመላክዎ በፊት መጠኑን እና የመቀበያ አድራሻውን ሁልጊዜ ያረጋግጡ::</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>እነኚ የቢትኮይን ክፍያ የመቀበያ አድራሻዎችዎ ናቸው:: ለእያንዳንዱ ግብይት አዲስ የመቀበያ አድራሻ እንዲጠቀሙ ይመከራል:: </translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;አድራሻ ቅዳ</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>ቅዳ &amp;መለያ ስም</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation> &amp;ቀይር</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>የአድራሻ ዝርዝር ላክ</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ኮማ ሴፓሬትድ ፋይል (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ወደ ውጪ መላክ አልተሳካም</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>የአድራሻ ዝርዝሩን ወደ %1 ለማስቀመጥ ሲሞከር ስህተት አጋጥሟል:: እባክዎ መልሰው ይሞክሩ::</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>አድራሻ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>የይለፍ-ሐረግ ንግግር</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>የይለፍ-ሐረግዎን ያስገቡ</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>አዲስ የይለፍ-ሐረግ</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>አዲስ የይለፍ-ሐረጉን ይድገሙት</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>አዲስ የይለፍ ሐረግዎን ወደ ቢትኮይን ቦርሳዎ ያስገቡ:: &lt;br/&gt;እባክዎ ለየይለፍ ሐረግዎ&lt;b&gt;አስር ወይም ከዚያ በላይ የዘፈቀደ ዓይነተ-ፊደላት&lt;/b&gt;, ወይም&lt;b&gt;ስምንት ወይም ከዚያ በላይ ቃላት&lt;/b&gt; ይጠቀሙ ::</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>የቢትኮይን ቦርሳውን አመስጥር</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>ይህ ክንዋኔ የቢትኮይን ቦርሳዎን ለመክፈት የቦርሳዎ ይለፍ-ሐረግ ያስፈልገዋል::</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>የቢትኮይን ቦርሳውን ክፈት</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>ይህ ክንዋኔ የቢትኮይን ቦርሳዎን ለመፍታት የቦርሳዎ ይለፍ-ሐረግ ያስፈልገዋል::</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>የቢትኮይን ቦርሳውን ፍታ</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>ይለፍ-ሐረግ ለውጥ</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>የድሮውን የይለፍ-ሐረግ እና አዲሱን የይለፍ-ሐረግ ወደ ቢትኮይን ቦርሳዎ ያስገቡ::</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>የቢትኮይን ቦርሳዎን ማመስጠር ያረጋግጡ</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>ማስጠንቀቂያ: የቢትኮይን ቦርሳዎን አመስጥረው የይለፍ-ሐረግዎን ካጡት&lt;b&gt;ቢትኮይኖቾን በሙሉ ያጣሉ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>እርግጠኛ ነዎት ቦርሳዎን ማመስጠር ይፈልጋሉ?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>ቦርሳዎ ምስጢር ተደርጓል</translation>
    </message>
    <message>
        <source>%1 will close now to finish the encryption process. Remember that encrypting your wallet cannot fully protect your bitcoins from being stolen by malware infecting your computer.</source>
        <translation>%1 የማመስጠር ሂደቱን ለመጨረስ አሁን ይዘጋል:: ያስታውሱ፣ ኮምፒተርዎ በተንኮል አዘል ሶፍትዌር ከተበከለ ቦርሳዎን ማመስጠር ቢትኮይኖቾን ሙሉበሙሉ እንዳይሰረቁ ሊከላከል አይችልም::</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>አስፈላጊ: ከ ቦርሳ ፋይልዎ ያከናወኗቸው ቀደም ያሉ ምትኬዎች በአዲስ በተፈጠረ የማመስጠሪያ ፋይል ውስጥ መተካት አለባቸው. ለደህንነት ሲባል, አዲሱን የተመሰጠ የቦርሳ ፋይል መጠቀም ሲጀመሩ ወዲያውኑ ቀደም ሲል ያልተመሰጠሩ የቦርሳ ፋይል ቅጂዎች ዋጋ ቢስ ይሆናሉ::</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>የቦርሳ ማመስጠር አልተሳካም</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>የቦርሳ ማመስጠር በውስጣዊ ስህተት ምክንያት አልተሳካም:: ቦርሳዎ አልተመሰጠረም::</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>የተሰጡት የይለፍ-ሐረግዎች አይዛመዱም::</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>ቦርሳ መክፈት አልተሳካም</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>ቦርሳ ለመፍታት ያስገቡት የይለፍ-ሐረግ ትክክል አልነበረም::</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>ቦርሳ መፍታት አልተሳካም </translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>የቦርሳ የይለፍ-ሐረግ በተሳካ ሁኔታ ተቀይሯል.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>ማስጠንቀቂያ: የ "Caps Lock" ቁልፍ በርቷል!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>አይፒ/ኔትማስክ  IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>ታግደዋል እስከ</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>ምልክትና መልእክት...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>ከኔትወርክ ጋራ በማመሳሰል ላይ ነው...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;አጠቃላይ እይታ</translation>
    </message>
    <message>
        <source>Node</source>
        <translation>እትር</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>የቦርሳ አጠቃላይ እይታ ኣሳይ</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;ግብይቶች</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>የግብይት ታሪክ ያስሱ</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>ውጣ</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>አፕሊኬሽኑን አቁም</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;ስለ %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>ስለ %1 መረጃ አሳይ</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>ስለ &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>ስለ Qt መረጃ አሳይ</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;አማራጮች...</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QObject::QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>አድራሻ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ኮማ ሴፓሬትድ ፋይል (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>አድራሻ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ወደ ውጪ መላክ አልተሳካም</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ላክ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>በአሁኑ ማውጫ ውስጥ ያለውን መረጃ ወደ አንድ ፋይል ላክ</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>

==> bitcoin-0.20.0.tar.gz: bitcoin-0.20.0/src/qt/locale/bitcoin_am.ts <==
<TS language="am" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>አድራሻ ወይም መለያ ስም ለመቀየር ቀኙን ጠቅ ያድርጉ</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>አዲስ አድራሻ ፍጠር</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;አዲስ</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>አሁን የተመረጠውን አድራሻ ወደ ሲስተሙ ቅንጥብ ሰሌዳ ቅዳ</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;ቅዳ</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>ዝጋ</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>አሁን የተመረጠውን አድራሻ ከዝርዝሩ ውስጥ ሰርዝ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>በአሁኑ ማውጫ ውስጥ ያለውን መረጃ ወደ አንድ ፋይል ላክ</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ላክ</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;ሰርዝ</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>ገንዘብ/ኮይኖች የሚልኩለትን አድራሻ ይምረጡ</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>ገንዘብ/ኮይኖች የሚቀበሉበትን አድራሻ ይምረጡ</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>ምረጥ</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>የመላኪያ አድራሻዎች</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>የመቀበያ አድራሻዎች</translation>
    </message>
    <message>
        <source>These are your Bitcoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>እነኚ የቢትኮይን ክፍያ የመላኪያ አድራሻዎችዎ ናቸው:: ገንዘብ/ኮይኖች ከመላክዎ በፊት መጠኑን እና የመቀበያ አድራሻውን ሁልጊዜ ያረጋግጡ::</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;አድራሻ ቅዳ</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>ቅዳ &amp;መለያ ስም</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation> &amp;ቀይር</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>የአድራሻ ዝርዝር ላክ</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ኮማ ሴፓሬትድ ፋይል (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ወደ ውጪ መላክ አልተሳካም</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>የአድራሻ ዝርዝሩን ወደ %1 ለማስቀመጥ ሲሞከር ስህተት አጋጥሟል:: እባክዎ መልሰው ይሞክሩ::</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>አድራሻ</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>የይለፍ-ሐረግ ንግግር</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>የይለፍ-ሐረግዎን ያስገቡ</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>አዲስ የይለፍ-ሐረግ</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>አዲስ የይለፍ-ሐረጉን ይድገሙት</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>የቢትኮይን ቦርሳውን አመስጥር</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>ይህ ክንዋኔ የቢትኮይን ቦርሳዎን ለመክፈት የቦርሳዎ ይለፍ-ሐረግ ያስፈልገዋል::</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>የቢትኮይን ቦርሳውን ክፈት</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>ይህ ክንዋኔ የቢትኮይን ቦርሳዎን ለመፍታት የቦርሳዎ ይለፍ-ሐረግ ያስፈልገዋል::</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>የቢትኮይን ቦርሳውን ፍታ</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>ይለፍ-ሐረግ ለውጥ</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>የቢትኮይን ቦርሳዎን ማመስጠር ያረጋግጡ</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR BITCOINS&lt;/b&gt;!</source>
        <translation>ማስጠንቀቂያ: የቢትኮይን ቦርሳዎን አመስጥረው የይለፍ-ሐረግዎን ካጡት&lt;b&gt;ቢትኮይኖቾን በሙሉ ያጣሉ&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>እርግጠኛ ነዎት ቦርሳዎን ማመስጠር ይፈልጋሉ?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>ቦርሳዎ ምስጢር ተደርጓል</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>አስፈላጊ: ከ ቦርሳ ፋይልዎ ያከናወኗቸው ቀደም ያሉ ምትኬዎች በአዲስ በተፈጠረ የማመስጠሪያ ፋይል ውስጥ መተካት አለባቸው. ለደህንነት ሲባል, አዲሱን የተመሰጠ የቦርሳ ፋይል መጠቀም ሲጀመሩ ወዲያውኑ ቀደም ሲል ያልተመሰጠሩ የቦርሳ ፋይል ቅጂዎች ዋጋ ቢስ ይሆናሉ::</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>የቦርሳ ማመስጠር አልተሳካም</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>የቦርሳ ማመስጠር በውስጣዊ ስህተት ምክንያት አልተሳካም:: ቦርሳዎ አልተመሰጠረም::</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>የተሰጡት የይለፍ-ሐረግዎች አይዛመዱም::</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>ቦርሳ መክፈት አልተሳካም</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>ቦርሳ ለመፍታት ያስገቡት የይለፍ-ሐረግ ትክክል አልነበረም::</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>ቦርሳ መፍታት አልተሳካም </translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>የቦርሳ የይለፍ-ሐረግ በተሳካ ሁኔታ ተቀይሯል.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>ማስጠንቀቂያ: የ "Caps Lock" ቁልፍ በርቷል!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>አይፒ/ኔትማስክ  IP/Netmask</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>ታግደዋል እስከ</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>ምልክትና መልእክት...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>ከኔትወርክ ጋራ በማመሳሰል ላይ ነው...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;አጠቃላይ እይታ</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>የቦርሳ አጠቃላይ እይታ ኣሳይ</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;ግብይቶች</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>የግብይት ታሪክ ያስሱ</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>ውጣ</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>አፕሊኬሽኑን አቁም</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;ስለ %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>ስለ %1 መረጃ አሳይ</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>ስለ &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>ስለ Qt መረጃ አሳይ</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;አማራጮች...</translation>
    </message>
    </context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>CreateWalletActivity</name>
    </context>
<context>
    <name>CreateWalletDialog</name>
    </context>
<context>
    <name>EditAddressDialog</name>
    </context>
<context>
    <name>FreespaceChecker</name>
    </context>
<context>
    <name>HelpMessageDialog</name>
    </context>
<context>
    <name>Intro</name>
    </context>
<context>
    <name>ModalOverlay</name>
    </context>
<context>
    <name>OpenURIDialog</name>
    </context>
<context>
    <name>OpenWalletActivity</name>
    </context>
<context>
    <name>OptionsDialog</name>
    </context>
<context>
    <name>OverviewPage</name>
    </context>
<context>
    <name>PaymentServer</name>
    </context>
<context>
    <name>PeerTableModel</name>
    </context>
<context>
    <name>QObject</name>
    </context>
<context>
    <name>QRImageWidget</name>
    </context>
<context>
    <name>RPCConsole</name>
    </context>
<context>
    <name>ReceiveCoinsDialog</name>
    </context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>Address</source>
        <translation>አድራሻ</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    </context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    </context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    </context>
<context>
    <name>TransactionDesc</name>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(መለያ ስም የለም)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>ኮማ ሴፓሬትድ ፋይል (*.csv)</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>መለያ ስም</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>አድራሻ</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>ወደ ውጪ መላክ አልተሳካም</translation>
    </message>
    </context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;ላክ</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>በአሁኑ ማውጫ ውስጥ ያለውን መረጃ ወደ አንድ ፋይል ላክ</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    </context>
</TS>
